==> mktcenter-service-1.0.2-vg-20220526.102148-4-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityGoldenEggsService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.mktcenterservice.models.bo.MktActivityDetailAndPicture;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * @Author: lijunwei
 * @Time: 2019/2/25 10:17
 */
public interface ActivityGoldenEggsService {
    public ResponseData<JSONObject> addActivityGE(ActivityPriceBO bo,Integer type,String prefix,String wxPath, HttpServletRequest request) throws ParseException;
    public ResponseData<ActivityPriceBO> selectActivityGEById(ProbabilityVO vo);
    public ResponseData<ActivityPrizeBO> selectActivityGEByCode(String activePriceCode);
    public ResponseData<PageInfo<MktActivityPOWithBLOBs>> selectActivityEGLists(ActivityPriceParamVO vo, HttpServletRequest request);
    public ResponseData<JSONObject> updateActivityGE(ActivityPriceBO bo, HttpServletRequest request) throws ParseException;
    public ResponseData<JSONObject> updateActivityGENew(ActivityPriceBO bo, HttpServletRequest request) throws ParseException;
    public ResponseData<Integer> stopActivityEG(MktActivityPOWithBLOBs po, HttpServletRequest request);
    public ResponseData<PageInfo<AnalysisPriceResultVO>> selectAnalysisEG(ActivityPriceParamVO vo, HttpServletRequest request);
    public ResponseData<PageInfo<MktActivityPrizeRecordPO>> selectPrizePeople(ActivityPriceParamVO vo);
    public ResponseData<String> doVerificationCoupon(ActivityPriceParamVO vo, HttpServletRequest request);
    public MktActivityPOWithBLOBs getMktActivityPOWithBLOBs(ProbabilityVO vo);

    public ResponseData<String> doEggFrenzy(ProbabilityVO vo,String activityIden,String businessType,String sendType) throws ParseException;
    public ResponseData<List<MktActivityPrizeRecordPO>> getEGPrizeRecordList(MktActivityPrizeRecordPO po);
    public ResponseData<Map<String,Integer>>  residueMemberNumber(ProbabilityVO vo) throws ParseException;
    public ResponseData<Map<String,Integer>> addMemberNumber(ProbabilityVO vo) throws ParseException;
    public ResponseData<MktActivityPOWithBLOBs>  getActivityId(ProbabilityVO vo);
    public MktActivityDetailAndPicture getMktActivityPOWithBLOBsAndPicture(ProbabilityVO vo);
    public Long getMemberNumber(HttpServletRequest request, String mbrCondition);

    ResponseData<MktActivityDetailAndPicture> getMktActivityPOWithBLOBsAndPicture2C(ProbabilityVO vo);
}

==> mktcenter-service-1.5.3-vg-20220907.104407-2-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityGoldenEggsService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.centerstageservice.models.vo.SysImportCodeVO;
import com.bizvane.mktcenterservice.models.bo.MktActivityDetailAndPicture;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * @Author: lijunwei
 * @Time: 2019/2/25 10:17
 */
public interface ActivityGoldenEggsService {
    public ResponseData<JSONObject> addActivityGE(ActivityPriceBO bo,Integer type,String prefix,String wxPath, HttpServletRequest request) throws ParseException;
    public ResponseData<ActivityPriceBO> selectActivityGEById(ProbabilityVO vo);
    public ResponseData<ActivityPrizeBO> selectActivityGEByCode(String activePriceCode);
    public ResponseData<PageInfo<MktActivityPOWithBLOBs>> selectActivityEGLists(ActivityPriceParamVO vo, HttpServletRequest request);
    public ResponseData<JSONObject> updateActivityGE(ActivityPriceBO bo, HttpServletRequest request) throws ParseException;
    public ResponseData<JSONObject> updateActivityGENew(ActivityPriceBO bo, HttpServletRequest request) throws ParseException;
    public ResponseData<Integer> stopActivityEG(MktActivityPOWithBLOBs po, HttpServletRequest request);
    public ResponseData<PageInfo<AnalysisPriceResultVO>> selectAnalysisEG(ActivityPriceParamVO vo, HttpServletRequest request);
    public ResponseData<PageInfo<MktActivityPrizeRecordPO>> selectPrizePeople(ActivityPriceParamVO vo);
    public ResponseData<String> doVerificationCoupon(ActivityPriceParamVO vo, HttpServletRequest request);
    public MktActivityPOWithBLOBs getMktActivityPOWithBLOBs(ProbabilityVO vo);

    public ResponseData<String> doEggFrenzy(ProbabilityVO vo,String activityIden,String businessType,String sendType) throws ParseException;
    public ResponseData<List<MktActivityPrizeRecordPO>> getEGPrizeRecordList(MktActivityPrizeRecordPO po);
    public ResponseData<Map<String,Integer>>  residueMemberNumber(ProbabilityVO vo) throws ParseException;
    public ResponseData<Map<String,Integer>> addMemberNumber(ProbabilityVO vo) throws ParseException;
    public ResponseData<MktActivityPOWithBLOBs>  getActivityId(ProbabilityVO vo);
    public MktActivityDetailAndPicture getMktActivityPOWithBLOBsAndPicture(ProbabilityVO vo);
    public Long getMemberNumber(HttpServletRequest request, String mbrCondition);

    ResponseData<MktActivityDetailAndPicture> getMktActivityPOWithBLOBsAndPicture2C(ProbabilityVO vo);

    ResponseData<JSONObject> addActivityGENew(ActivityPriceBO bo,Integer type,String prefix,String wxPath, HttpServletRequest request) throws ParseException;

    /**
     * 导入手机号白名单
     * @param url
     * @param stageUser
     * @return
     */
    ResponseData<SysImportCodeVO> importWhitePhone(String url, SysAccountPO stageUser);

    /**
     * 根据上传的URL地址获取手机号列表
     * @param url
     * @return
     */
    ResponseData getWhitePhoneListFromExcel(String url);
}
